/* gda-delimiter-tree.h
 *
 * Copyright (C) 2004 - 2005 Vivien Malerba
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef SQL_TREE_H
#define SQL_TREE_H

#include "gda-sql-delimiter.h"

/* statements */
GdaDelimiterStatement   *gda_delimiter_statement_build  (GdaDelimiterStatementType type, GList *expr_list);

/* expression */
GdaDelimiterExpr        *gda_delimiter_expr_build       (gchar *str, GList *pspec_list);

/* param spec */
GList                   *gda_delimiter_param_spec_build_simple (gchar *content);
GdaDelimiterParamSpec   *gda_delimiter_param_spec_build (GdaDelimiterParamSpecType type, char *content);

#endif
